package org.expeditee.items;

import java.awt.Graphics2D;


public class WidgetCorner extends Dot {
	
	private InteractiveWidget _widgetSource;

	WidgetCorner(int x, int y, int id, InteractiveWidget widgetSource) {
		super(x, y, id);
		if (widgetSource == null) throw new NullPointerException("widgetSource");
		_widgetSource = widgetSource;
	}

	@Override
	protected void updatePolygon() {
		super.updatePolygon();
		if (_widgetSource != null) _widgetSource.onBoundsChanged();
	}

	@Override
	public void setPosition(int x, int y) {

		if (_widgetSource != null) { // _widgetSource == null on construction
			if (!_widgetSource.setPositions(this, x, y))
				super.setPosition(x, y);
		} else super.setPosition(x, y);
	}

	@Override
	public void onParentFameHidden() {
		super.onParentFameHidden();
		_widgetSource.onParentFameHidden();
	}

	@Override
	public void onParentFameShown() {
		super.onParentFameShown();
		_widgetSource.onParentFameShown();
	}

	@Override
	public void onRemovedFromFrame() {
		super.onRemovedFromFrame();
		_widgetSource.onRemovedFromFrame();
	}

	@Override
	public void onAddedToFrame() {
		super.onAddedToFrame();
		_widgetSource.onAddedToFrame();
	}

	public InteractiveWidget getWidgetSource() {
		return _widgetSource;
	}
	
	@Override
	public void paint(Graphics2D g) {
		if (InteractiveWidget.isExepiteeHighlightingEnabled()) { // only paint if flag is set to true
			super.paint(g);
		}
		_widgetSource.paint(g, this);	
	}
	
	@Override
	public void setAnnotation(boolean val) {
		// Ignore
	}

	@Override
	public boolean isAnnotation() {
		return false;
	}


	@Override
	public String toString() {
		return "WidgetCorner: [" + this.getX() + "," +  this.getY() + "]";
	}
	
	
}
